==> 2025-12-27-14-41-25-dnaas-dnaas_v1.1.3.zip: CHANGES_LOG.md <==
## 注意!
这是一个免费发布的, 基于免费开源项目的脚本.
本脚本仅用于编程学习相关, 请不要将其用于非法盈利!
你可以在这里找到该脚本的相关开源信息: https://github.com/arnold2957/dnaas
如果你是从他人手中购买或其他付费方式中获得的本脚本, 烦请向平台方举报"非法倒卖".
感谢支持!


**新版本!**
==v1.1.3==
加大了长时间直行与之后左转之间的等待时间. 以进一步解决部分设备无法左转的问题.

关于钓鱼的问题, 新版钓鱼使用两个完全相同的图标来进行下饵和收杆, 因此暂时还不能制作可用的钓鱼脚本.


**历史更新**
==v1.1.2==
部分任务和部分设备会偶尔出现长距离移动后无法往左走的情况. 目前的简易方案是对部分地图在长距离往左走后暂停移动0.5秒. 如果你的设备上依旧无法正确抵达, 欢迎联系我进行更多的测试.
修复了60jjb开局后无法后退的问题.
修复了65mod开局长距离移动后偶尔无法往左走的问题.
删除了40夜航的开局自动走路.
修复了迷津无法进入的问题.

==v1.1.1==
调整了控制人物移动的操作范围, 以解决部分设备中人物无法移动的问题.(感谢[@无月无星的夜]的协助.)
调整了部分任务中控制镜头的操作范围, 以解决部分任务错乱的问题.

注意, 移动问题应该得到了完全的修复. 如果你遇到了无法正确就位的问题, 请@我.
注意, 部分含有镜头移动的任务可能无法正确生效, 包括但不限于红豆本和肉鸽. 烦请等待进一步修复.

==v1.1.0==
这是一个紧急修复版本.
修复了云游戏待机界面ui的识别导致无法开始任务的问题.
修复了无法位移的问题.

注意, 新版本修改了云游戏的操作方法, 但目前的位移方案依旧存在误差.
如果你遇到问题请在群里@我, 并写明发生位移问题(比如无法抵达), 关卡名称, 发生频率和使用角色.
感谢大家的支持!

==v1.0.38==
新增了对于80级mod本的支持.

==v1.0.37==
优化: 现在开局释放Q技能后, 也会执行防掉线逻辑.
优化: 现在可以尝试进入肉鸽最后boss的门.

==v1.0.36==
优化: 现在肉鸽可以识别最后boss的图标.

==v1.0.35==
优化: 当没有勾选任何技能释放时, 会从三个动作(二段跳, 右键, 换弹)中随机挑选一个执行, 重复三次.
新增: 当云游戏偶尔出现账号选择界面的时候, 可以点击上次登录的那个账号.
优化: 简化了迷津的逻辑, 和普通流程进行统一, 以接入诸如登录等等功能.
优化: 现在肉鸽可以进入休整场景.
修复: 当检测到没有鱼的时候, 会结束钓鱼任务(@shlhu, issue#11)

==v1.0.34==
修复: 现在钓鱼不会退出了.
新增: 新增了测试版本的迷津. 限定六命夫人和蓝色脉动, 目前只在70级肉鸽上测试.
优化: 连接不上服务器的弹窗改为内置文本.

==v1.0.33==
修复: 现在总是会点击钓鱼的空白区域.
新增: 现在脚本可以通过访问github来自动进行检查新版本并下载了.

==v1.0.32==
新增: 新增了红珠本的第四个房间. 虽然经过测试已经可以平均在300秒以内完成了, 但是稳妥起见还是单独开了测试版本.
优化: 将开密函-驱离改为复位(而不是开场乱走).
优化: 现在悠闲钓鱼会识别新图鉴, 同时会经常的点击空白位置来跳过所有可能的弹窗.

==v1.0.31==
修复: 修复会因为提升"钓到鱼了"导致钓鱼中断的问题.

==v1.0.30==
修复: 悠闲钓鱼只会钓第一条鱼的问题.
优化: 现在经验本会判定左边打到100%或右上角前往撤离点.
优化: 释放Q技能后的远程攻击可能会导致继续的问题.

==v1.0.29==
新增: 新增了魔之楔(不是夜航手册!)的任务, 可以刷取40, 60, 100级的魔之楔大混池.
新增: 新增了悠闲钓鱼. 由于我目前没有悠闲, 欢迎反馈这个任务的相关问题!
修复: 修复了如果在退出副本时重启会额外扣掉一次已经完成副本的计数.
优化: 优化了红豆本的镜头调整和次数统计.
优化: 30火现在会直视地板, 以优化游戏性能. (据说有用.)
优化: 增加了Q技能释放后的等待时间, 以防止射击有时无效的问题.

==v1.0.28==
优化: 优化了60级的凝珠本.
修复: 修复偶尔的无法撤离的情况.
注意, 1026版本会错误的输出调试信息, 烦请删除那些数据()

==v1.0.27==
新增: 60级凝珠(测试版本). 只会开3个人质, 人质后的那部分地图也有一张稀有地图没做. 要求装备长矛且不是春辉戟, 装备穿引共鸣, 蓝+5迅捷和紫+5蓄力攻速.
新增: 现在检测到勘察的时候会强制结束任务, 以防止在多人联机金币本的时候使用本脚本.
新增: 在多人联机游戏中, 会识别并同意继续游戏的请求.
新增: 30mod. 和65mod是相同地图(应该是的).
修复: 会错误的输出debug信息(为啥python不能用宏来控制捏).

==v1.0.26==
修复: 重启后某些运行时数据没有重置的问题.
修复: 部分设备无法点击左上角导致无法重进/无法复位
新增: 当不开启任何技能, 会每隔20秒释放一次射击+换弹+原地二段跳来防止被踢出云游戏.
修复: 修复了材料本会卡住不能进本的问题.
优化: 现在暂时不会重启模拟器.
优化: 因为部分设备的右上角不会因为完成任务而更新, 50经验本现在检测左边的进度条是否为100%.

==v1.0.25==
修复: 修复了导致70武器材料本识别错误的问题.
修复: q技能会反复释放而不是只释放一次的问题.
优化: 关闭了70武器材料本的识别提示.

==v1.0.24==
修复: 尝试修复武器突破本复位后第一次移动丢失的问题.
修复: 50经验本增加了第三次复位.
修复: q技能会反复释放而不是只释放一次的问题.
新增: 跳过网易云游戏 taptap云游戏等的重启.
优化: 修改了开密函任务名.
修复: 修改了70皎皎币的默认轮数.

==v1.0.23==
新增: 新增了50级的mod本.
新增: 对选择所有六个元素的突破材料本的支持.
新增: 加入了对港澳台/国际服游戏的重启. 目前使用的是"com.panstudio.gplay.duetnightabyss.arpg.global", 如果有国际服云游戏的包也欢迎告知.
修复: 修复"Q技能释放一次"会不停释放的问题.
优化: 优化了开核桃的生存, 现在使用10火的版本可以全自动. 半自动已经更名为无巧手.
优化: 优化了开核桃相关的任务文本和重启逻辑. 现在可以正常停止.
优化: 了转反! 50经验本现在会从右边走.
优化: 优化了50经验本, 现在会等到100%进度再撤离.
优化: 稍微修改了70突破材料本的逻辑.
优化: 修改了70突破材料在第二次复位后进行的检测. 

==v1.0.22==
额外参数指的是mod本的从上往下数第几个. 无关心会从前四个里随机挑选一个出来.
请尽量使用成女进行跑位. 如果要主控主角, 请务必关闭e技能! e技能自带位移会导致偏差!

新增: 云游戏登录的开始游戏和我知道啦的检测.
修复: 超过60级后mod本选择会有偏差的问题.
修复: 默认等级和目标等级一致时会卡住不能进本的问题.
优化: 70mod已经改为原地挂机.
优化: 武器突破材料本的第二次复位后的前进距离缩短了一些.
优化: 武器突破材料本会加入一次检测和校正.

==v1.0.21==
新增: 现已支持mod选择. 重启时, 可以从选择的路径重新刷mod.
修复: 修复会卡在委托和未选择任务的情况.
新增: 现在武器材料本中会释放技能.
优化: 现在武器本会尝试跑到底.
优化: 现在更高效的检测对比当前复位的是哪个区块.

==v1.0.20==
修复: 修复了一个会导致密函奖励选择错误的问题. 非常抱歉.
修复: 修复了模拟器无法被关闭的问题. 现在当adb连接错误的时候, mumu模拟器可以自动重启.
修复: 当退出副本的时候进行游戏重启, 无法继续的问题.
修复: 70经验本开锁的前后偏移的问题.

==v1.0.19==
优化: 部分设备会出现识别错误导致错误的认为是密函选择环节, 调整了密函选择的点击位置以避免误触.
修复: E技能计时器不工作的问题. 

==v1.0.18==
新增: 对截图尺寸的检查, 以提示错误的模拟器分辨率.
修复: 云游戏现在支持70武器突破材料. 注意, 测试版本, 可能会有一定程度的识别问题.
修复: 武器突破材料在检查没有开锁后会尝试回头走一段距离.
修复: 删除了随机扰动. (早就该删了!)
修复: 自定义波数失效的问题.

==v1.0.17==
新增: 新增了70级的武器突破材料. 注意, 测试版本, 可能会有一定程度的卡脚.
新增: 只在最后一轮使用绿书.
优化: 默认E的时间已经改为7秒.
修复: 现在超过尝试次数时会重启.
优化: 修改了人物经验本的移动逻辑. 现在会先跑一段距离, 然后等待一段时间, 然后继续跑一段距离. 最后, 修改了结尾时的面朝方向.
优化: 修改了尝试定位时的文本.
优化: 在总结中新增了任务名.
优化: 优化了人物经验本的文字说明. 
优化: 修改了任务图标的点击位置以避免卡死.
优化: 大幅优化了定位逻辑, 以避免各种卡死的问题.

==v1.0.15==
新增: 现在可以从桌面启动皎皎币 经验本和材料本. 并且当这些本遇到问题重启时, 可以正常重启.
优化: 稍微修改了驱离开场的移动, 以避免卡电梯的问题.
优化: 现在已将驱离和半自动分开. 半自动不会开场移动, 只会原地挂机.
修复: 修复了E随机扰动的计数错误的问题.
优化: 50经验本现在会复位2次.
优化: 65mod和对应的70皎皎币地图进行了优化, 现在会进行一次二段跳.
优化: 鉴于总是有人跟我反馈E技能释放有问题, 现已加入打印内部计时器的功能.

==v1.0.16--
新增: 加入了免费声明.
修复: 云游戏有些时候刚启动就会被击杀的问题.
修复: 无法停止的问题.

==v1.0.14==
新增: 驱离和半自动已经合并. 该任务可以执行简单的功能, 包括: 驱离, 自动点下一轮, 自动放Q和E, 自动开密函(选第一个), 自动选密函奖励(也是第一个).
你可以用这个任务刷所有的驱离和较为简单的任务. 但是注意, 该任务不会解锁也不会移动(只有一个固定的下电梯操作).
新增: 现在可以自动按复苏(待测试云游戏).
新增: 现在可以控制自动放Q. 同时在放Q后自动附加一次远程攻击和reload.
(关于放Q和附加远程攻击: 西比尔的雷球有些时候不会被识别为敌人, 经过研究攻击雷球可以有较大的概率刷新ai. 但是也有偶发的雷球召唤了ai依旧发呆的情况. 如果有更好的方案请告诉我.)
优化: 稍微优化了30火本的站位.
优化: 现在经验本在最后上台子的时候会尝试跳2次.
修复: 现在多波次不会错误的将同一个波次反复计算.
优化: 现在应该不会卡在放弃挑战了.
修复: 现在70jjb会按照说明的那样只刷1轮.
修复: 现在70jjb可以刷取65mod同款地图.

==v1.0.13==
对云游戏的开锁进行了适配.
现已加入50经验本与30火(默认10波).
50经验本只能刷一半的地图.

==v1.0.12==
现已加入自定义轮数.
70皎皎币的默认轮数改为2.
现在面板上的计时器计算一个小局的时间(例如, 15波10级火材料其中1波的时间.)
修改了施法间隔的计数方式. 现在不会有较高的延迟了.
现在会较快的开始释放第一个E技能.
现在会检查并关闭小月卡画面, 并记录. (截图清晰度不足, 或许需要更清晰的图片.)

==v1.0.10==
稍微优化了65mod的寻路. 现在应该不会卡车了.
优化了15火全自动的开场. 现在不会走过头了.
驱离的开始移动配置错了, 现在可以下电梯了.
已加入70皎皎币. 能刷3张图里的2张图.

==v1.0.11==
修复了有时候无法检测到放弃战斗导致脚本中止的问题.
(以及, 改了版本号)

==v1.0.8==
新增: 现在超时检查可以自定义.
新增: 现在可以尝试使用绿书.
新增: 现在增加了15火半自动.
修复: 现在驱离不会复位了. (一秒墙中人也太吓人了)
优化: 优化了15火全自动的开场逻辑. 现在不会往前一直走, 完成机关后也会往右走一点
优化: 现在不会反复提示 已在副本中.
优化: 现在计数器不会反复计数.
优化: 现在E技能的自动释放具有随机扰动. 

==v1.0.9==
优化: 降低了随机扰动的方差.
优化: 驱离加了开局自动往前走.

==v1.0.7==
全自动15波火材料. 要求巧手. 260+范围水母.

==v1.0.6==
现已支持云游戏. 打不开游戏的一律建议云游戏启动.

==v1.0.5==
修复了60皎皎币在无法刷的地图开始移动的问题.
新增了简易的15火无尽探险. 目前需要先手动跑位, 15波后自动撤离.

==v1.0.4==
新增: 检测云游戏的角色复位
新增: 自定义E技能的释放间隔
优化: 使用复位来到达65mod的机制旁边.

==v1.0.3==
测试版本
包含65皎皎币和65mod.
65皎皎币只能刷一半的地图
可能会有一些问题, 不愿意尝试的可以等稳定版本.

==v1.0.2==
修复: 修复了没法进esc界面的问题.
修复: 修复了有时候会卡在电梯井里的问题.

==> 2026-01-28-21-46-05-dnaas-dnaas_v1.1.7.zip: CHANGES_LOG.md <==
## 注意! 
这是一个免费发布的, 基于免费开源项目的脚本.
本脚本仅用于编程学习相关, 请不要将其用于非法盈利!
你可以在这里找到该脚本的相关开源信息: https://github.com/arnold2957/dnaas
如果你是从他人手中购买或其他付费方式中获得的本脚本, 烦请向平台方举报"非法倒卖".
感谢支持!


**新版本!**
==v1.1.7==
修复了80夜航无法识别"无关心"额外参数的问题, 同时支持了2和3. 现在80夜航的额外参数支持12345和无关心.

**已知问题**
关于钓鱼的问题, 新版钓鱼使用两个完全相同的图标来进行下饵和收杆, 因此暂时还不能制作可用的钓鱼脚本.
红豆本依旧存在问题.

**历史更新**
==v1.1.6==
新增了80mod本的第4个和第5个任务.
武器突破材料第二个复位点的行动中, 略微增加了第一次往前走的距离.
新增了对于30帧的兼容模式.

==v1.1.5==
修复了30帧数下镜头调整过大的问题.

==v1.1.4==
现已加入关闭云游戏启动前公告的功能.
修改了"往左"指令的移动距离, 以避免直行后出现往左命令失效的问题. 该修改涉及的任务有: 经验本50, 夜航50, 皎皎币70, 武器突破70, 红豆60, 密函-探险无尽.
修复了红豆本因为ai开锁导致无法继续的问题.
修复了进入迷津罚站的问题.

不是bug:
如果你的角色无法二段跳而是螺旋飞跃, 请修改按键布局.
某些副本不会取消Q技能的持续, 因此后半段移动会出现速度不同并导致问题, 比如黎瑟或赛琪.
矮个角色因为镜头视角的区别, 在武器突破70的后半段会无法识别. 请使用高个子的角色.

==v1.1.3==
加大了长时间直行与之后左转之间的等待时间. 以进一步解决部分设备无法左转的问题.

==v1.1.2==
部分任务和部分设备会偶尔出现长距离移动后无法往左走的情况. 目前的简易方案是对部分地图在长距离往左走后暂停移动0.5秒. 如果你的设备上依旧无法正确抵达, 欢迎联系我进行更多的测试.
修复了60jjb开局后无法后退的问题.
修复了65mod开局长距离移动后偶尔无法往左走的问题.
删除了40夜航的开局自动走路.
修复了迷津无法进入的问题.

==v1.1.1==
调整了控制人物移动的操作范围, 以解决部分设备中人物无法移动的问题.(感谢[@无月无星的夜]的协助.)
调整了部分任务中控制镜头的操作范围, 以解决部分任务错乱的问题.

注意, 移动问题应该得到了完全的修复. 如果你遇到了无法正确就位的问题, 请@我.
注意, 部分含有镜头移动的任务可能无法正确生效, 包括但不限于红豆本和肉鸽. 烦请等待进一步修复.

==v1.1.0==
这是一个紧急修复版本.
修复了云游戏待机界面ui的识别导致无法开始任务的问题.
修复了无法位移的问题.

注意, 新版本修改了云游戏的操作方法, 但目前的位移方案依旧存在误差.
如果你遇到问题请在群里@我, 并写明发生位移问题(比如无法抵达), 关卡名称, 发生频率和使用角色.
感谢大家的支持!

==v1.0.38==
新增了对于80级mod本的支持.

==v1.0.37==
优化: 现在开局释放Q技能后, 也会执行防掉线逻辑.
优化: 现在可以尝试进入肉鸽最后boss的门.

==v1.0.36==
优化: 现在肉鸽可以识别最后boss的图标.

==v1.0.35==
优化: 当没有勾选任何技能释放时, 会从三个动作(二段跳, 右键, 换弹)中随机挑选一个执行, 重复三次.
新增: 当云游戏偶尔出现账号选择界面的时候, 可以点击上次登录的那个账号.
优化: 简化了迷津的逻辑, 和普通流程进行统一, 以接入诸如登录等等功能.
优化: 现在肉鸽可以进入休整场景.
修复: 当检测到没有鱼的时候, 会结束钓鱼任务(@shlhu, issue#11)

==v1.0.34==
修复: 现在钓鱼不会退出了.
新增: 新增了测试版本的迷津. 限定六命夫人和蓝色脉动, 目前只在70级肉鸽上测试.
优化: 连接不上服务器的弹窗改为内置文本.

==v1.0.33==
修复: 现在总是会点击钓鱼的空白区域.
新增: 现在脚本可以通过访问github来自动进行检查新版本并下载了.

==v1.0.32==
新增: 新增了红珠本的第四个房间. 虽然经过测试已经可以平均在300秒以内完成了, 但是稳妥起见还是单独开了测试版本.
优化: 将开密函-驱离改为复位(而不是开场乱走).
优化: 现在悠闲钓鱼会识别新图鉴, 同时会经常的点击空白位置来跳过所有可能的弹窗.

==v1.0.31==
修复: 修复会因为提升"钓到鱼了"导致钓鱼中断的问题.

==v1.0.30==
修复: 悠闲钓鱼只会钓第一条鱼的问题.
优化: 现在经验本会判定左边打到100%或右上角前往撤离点.
优化: 释放Q技能后的远程攻击可能会导致继续的问题.

==v1.0.29==
新增: 新增了魔之楔(不是夜航手册!)的任务, 可以刷取40, 60, 100级的魔之楔大混池.
新增: 新增了悠闲钓鱼. 由于我目前没有悠闲, 欢迎反馈这个任务的相关问题!
修复: 修复了如果在退出副本时重启会额外扣掉一次已经完成副本的计数.
优化: 优化了红豆本的镜头调整和次数统计.
优化: 30火现在会直视地板, 以优化游戏性能. (据说有用.)
优化: 增加了Q技能释放后的等待时间, 以防止射击有时无效的问题.

==v1.0.28==
优化: 优化了60级的凝珠本.
修复: 修复偶尔的无法撤离的情况.
注意, 1026版本会错误的输出调试信息, 烦请删除那些数据()

==v1.0.27==
新增: 60级凝珠(测试版本). 只会开3个人质, 人质后的那部分地图也有一张稀有地图没做. 要求装备长矛且不是春辉戟, 装备穿引共鸣, 蓝+5迅捷和紫+5蓄力攻速.
新增: 现在检测到勘察的时候会强制结束任务, 以防止在多人联机金币本的时候使用本脚本.
新增: 在多人联机游戏中, 会识别并同意继续游戏的请求.
新增: 30mod. 和65mod是相同地图(应该是的).
修复: 会错误的输出debug信息(为啥python不能用宏来控制捏).

==v1.0.26==
修复: 重启后某些运行时数据没有重置的问题.
修复: 部分设备无法点击左上角导致无法重进/无法复位
新增: 当不开启任何技能, 会每隔20秒释放一次射击+换弹+原地二段跳来防止被踢出云游戏.
修复: 修复了材料本会卡住不能进本的问题.
优化: 现在暂时不会重启模拟器.
优化: 因为部分设备的右上角不会因为完成任务而更新, 50经验本现在检测左边的进度条是否为100%.

==v1.0.25==
修复: 修复了导致70武器材料本识别错误的问题.
修复: q技能会反复释放而不是只释放一次的问题.
优化: 关闭了70武器材料本的识别提示.

==v1.0.24==
修复: 尝试修复武器突破本复位后第一次移动丢失的问题.
修复: 50经验本增加了第三次复位.
修复: q技能会反复释放而不是只释放一次的问题.
新增: 跳过网易云游戏 taptap云游戏等的重启.
优化: 修改了开密函任务名.
修复: 修改了70皎皎币的默认轮数.

==v1.0.23==
新增: 新增了50级的mod本.
新增: 对选择所有六个元素的突破材料本的支持.
新增: 加入了对港澳台/国际服游戏的重启. 目前使用的是"com.panstudio.gplay.duetnightabyss.arpg.global", 如果有国际服云游戏的包也欢迎告知.
修复: 修复"Q技能释放一次"会不停释放的问题.
优化: 优化了开核桃的生存, 现在使用10火的版本可以全自动. 半自动已经更名为无巧手.
优化: 优化了开核桃相关的任务文本和重启逻辑. 现在可以正常停止.
优化: 了转反! 50经验本现在会从右边走.
优化: 优化了50经验本, 现在会等到100%进度再撤离.
优化: 稍微修改了70突破材料本的逻辑.
优化: 修改了70突破材料在第二次复位后进行的检测. 

==v1.0.22==
额外参数指的是mod本的从上往下数第几个. 无关心会从前四个里随机挑选一个出来.
请尽量使用成女进行跑位. 如果要主控主角, 请务必关闭e技能! e技能自带位移会导致偏差!

新增: 云游戏登录的开始游戏和我知道啦的检测.
修复: 超过60级后mod本选择会有偏差的问题.
修复: 默认等级和目标等级一致时会卡住不能进本的问题.
优化: 70mod已经改为原地挂机.
优化: 武器突破材料本的第二次复位后的前进距离缩短了一些.
优化: 武器突破材料本会加入一次检测和校正.

==v1.0.21==
新增: 现已支持mod选择. 重启时, 可以从选择的路径重新刷mod.
修复: 修复会卡在委托和未选择任务的情况.
新增: 现在武器材料本中会释放技能.
优化: 现在武器本会尝试跑到底.
优化: 现在更高效的检测对比当前复位的是哪个区块.

==v1.0.20==
修复: 修复了一个会导致密函奖励选择错误的问题. 非常抱歉.
修复: 修复了模拟器无法被关闭的问题. 现在当adb连接错误的时候, mumu模拟器可以自动重启.
修复: 当退出副本的时候进行游戏重启, 无法继续的问题.
修复: 70经验本开锁的前后偏移的问题.

==v1.0.19==
优化: 部分设备会出现识别错误导致错误的认为是密函选择环节, 调整了密函选择的点击位置以避免误触.
修复: E技能计时器不工作的问题. 

==v1.0.18==
新增: 对截图尺寸的检查, 以提示错误的模拟器分辨率.
修复: 云游戏现在支持70武器突破材料. 注意, 测试版本, 可能会有一定程度的识别问题.
修复: 武器突破材料在检查没有开锁后会尝试回头走一段距离.
修复: 删除了随机扰动. (早就该删了!)
修复: 自定义波数失效的问题.

==v1.0.17==
新增: 新增了70级的武器突破材料. 注意, 测试版本, 可能会有一定程度的卡脚.
新增: 只在最后一轮使用绿书.
优化: 默认E的时间已经改为7秒.
修复: 现在超过尝试次数时会重启.
优化: 修改了人物经验本的移动逻辑. 现在会先跑一段距离, 然后等待一段时间, 然后继续跑一段距离. 最后, 修改了结尾时的面朝方向.
优化: 修改了尝试定位时的文本.
优化: 在总结中新增了任务名.
优化: 优化了人物经验本的文字说明. 
优化: 修改了任务图标的点击位置以避免卡死.
优化: 大幅优化了定位逻辑, 以避免各种卡死的问题.

==v1.0.15==
新增: 现在可以从桌面启动皎皎币 经验本和材料本. 并且当这些本遇到问题重启时, 可以正常重启.
优化: 稍微修改了驱离开场的移动, 以避免卡电梯的问题.
优化: 现在已将驱离和半自动分开. 半自动不会开场移动, 只会原地挂机.
修复: 修复了E随机扰动的计数错误的问题.
优化: 50经验本现在会复位2次.
优化: 65mod和对应的70皎皎币地图进行了优化, 现在会进行一次二段跳.
优化: 鉴于总是有人跟我反馈E技能释放有问题, 现已加入打印内部计时器的功能.

==v1.0.16--
新增: 加入了免费声明.
修复: 云游戏有些时候刚启动就会被击杀的问题.
修复: 无法停止的问题.

==v1.0.14==
新增: 驱离和半自动已经合并. 该任务可以执行简单的功能, 包括: 驱离, 自动点下一轮, 自动放Q和E, 自动开密函(选第一个), 自动选密函奖励(也是第一个).
你可以用这个任务刷所有的驱离和较为简单的任务. 但是注意, 该任务不会解锁也不会移动(只有一个固定的下电梯操作).
新增: 现在可以自动按复苏(待测试云游戏).
新增: 现在可以控制自动放Q. 同时在放Q后自动附加一次远程攻击和reload.
(关于放Q和附加远程攻击: 西比尔的雷球有些时候不会被识别为敌人, 经过研究攻击雷球可以有较大的概率刷新ai. 但是也有偶发的雷球召唤了ai依旧发呆的情况. 如果有更好的方案请告诉我.)
优化: 稍微优化了30火本的站位.
优化: 现在经验本在最后上台子的时候会尝试跳2次.
修复: 现在多波次不会错误的将同一个波次反复计算.
优化: 现在应该不会卡在放弃挑战了.
修复: 现在70jjb会按照说明的那样只刷1轮.
修复: 现在70jjb可以刷取65mod同款地图.

==v1.0.13==
对云游戏的开锁进行了适配.
现已加入50经验本与30火(默认10波).
50经验本只能刷一半的地图.

==v1.0.12==
现已加入自定义轮数.
70皎皎币的默认轮数改为2.
现在面板上的计时器计算一个小局的时间(例如, 15波10级火材料其中1波的时间.)
修改了施法间隔的计数方式. 现在不会有较高的延迟了.
现在会较快的开始释放第一个E技能.
现在会检查并关闭小月卡画面, 并记录. (截图清晰度不足, 或许需要更清晰的图片.)

==v1.0.10==
稍微优化了65mod的寻路. 现在应该不会卡车了.
优化了15火全自动的开场. 现在不会走过头了.
驱离的开始移动配置错了, 现在可以下电梯了.
已加入70皎皎币. 能刷3张图里的2张图.

==v1.0.11==
修复了有时候无法检测到放弃战斗导致脚本中止的问题.
(以及, 改了版本号)

==v1.0.8==
新增: 现在超时检查可以自定义.
新增: 现在可以尝试使用绿书.
新增: 现在增加了15火半自动.
修复: 现在驱离不会复位了. (一秒墙中人也太吓人了)
优化: 优化了15火全自动的开场逻辑. 现在不会往前一直走, 完成机关后也会往右走一点
优化: 现在不会反复提示 已在副本中.
优化: 现在计数器不会反复计数.
优化: 现在E技能的自动释放具有随机扰动. 

==v1.0.9==
优化: 降低了随机扰动的方差.
优化: 驱离加了开局自动往前走.

==v1.0.7==
全自动15波火材料. 要求巧手. 260+范围水母.

==v1.0.6==
现已支持云游戏. 打不开游戏的一律建议云游戏启动.

==v1.0.5==
修复了60皎皎币在无法刷的地图开始移动的问题.
新增了简易的15火无尽探险. 目前需要先手动跑位, 15波后自动撤离.

==v1.0.4==
新增: 检测云游戏的角色复位
新增: 自定义E技能的释放间隔
优化: 使用复位来到达65mod的机制旁边.

==v1.0.3==
测试版本
包含65皎皎币和65mod.
65皎皎币只能刷一半的地图
可能会有一些问题, 不愿意尝试的可以等稳定版本.

==v1.0.2==
修复: 修复了没法进esc界面的问题.
修复: 修复了有时候会卡在电梯井里的问题.
